import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListApplicationAuthenticationMethodsRequest, ListApplicationAuthenticationMethodsResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListApplicationAuthenticationMethodsCommand}.
 */
export interface ListApplicationAuthenticationMethodsCommandInput extends ListApplicationAuthenticationMethodsRequest {
}
/**
 * @public
 *
 * The output of {@link ListApplicationAuthenticationMethodsCommand}.
 */
export interface ListApplicationAuthenticationMethodsCommandOutput extends ListApplicationAuthenticationMethodsResponse, __MetadataBearer {
}
declare const ListApplicationAuthenticationMethodsCommand_base: {
    new (input: ListApplicationAuthenticationMethodsCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationAuthenticationMethodsCommandInput, ListApplicationAuthenticationMethodsCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListApplicationAuthenticationMethodsCommandInput): import("@smithy/smithy-client").CommandImpl<ListApplicationAuthenticationMethodsCommandInput, ListApplicationAuthenticationMethodsCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists all of the authentication methods supported by the specified application.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, ListApplicationAuthenticationMethodsCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, ListApplicationAuthenticationMethodsCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // ListApplicationAuthenticationMethodsRequest
 *   ApplicationArn: "STRING_VALUE", // required
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new ListApplicationAuthenticationMethodsCommand(input);
 * const response = await client.send(command);
 * // { // ListApplicationAuthenticationMethodsResponse
 * //   AuthenticationMethods: [ // AuthenticationMethods
 * //     { // AuthenticationMethodItem
 * //       AuthenticationMethodType: "IAM",
 * //       AuthenticationMethod: { // AuthenticationMethod Union: only one key present
 * //         Iam: { // IamAuthenticationMethod
 * //           ActorPolicy: "DOCUMENT_VALUE", // required
 * //         },
 * //       },
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListApplicationAuthenticationMethodsCommandInput - {@link ListApplicationAuthenticationMethodsCommandInput}
 * @returns {@link ListApplicationAuthenticationMethodsCommandOutput}
 * @see {@link ListApplicationAuthenticationMethodsCommandInput} for command's `input` shape.
 * @see {@link ListApplicationAuthenticationMethodsCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ResourceNotFoundException} (client fault)
 *  <p>Indicates that a requested resource is not found.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class ListApplicationAuthenticationMethodsCommand extends ListApplicationAuthenticationMethodsCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListApplicationAuthenticationMethodsRequest;
            output: ListApplicationAuthenticationMethodsResponse;
        };
        sdk: {
            input: ListApplicationAuthenticationMethodsCommandInput;
            output: ListApplicationAuthenticationMethodsCommandOutput;
        };
    };
}
