import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { ListTrustedTokenIssuersRequest, ListTrustedTokenIssuersResponse } from "../models/models_0";
import { ServiceInputTypes, ServiceOutputTypes, SSOAdminClientResolvedConfig } from "../SSOAdminClient";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link ListTrustedTokenIssuersCommand}.
 */
export interface ListTrustedTokenIssuersCommandInput extends ListTrustedTokenIssuersRequest {
}
/**
 * @public
 *
 * The output of {@link ListTrustedTokenIssuersCommand}.
 */
export interface ListTrustedTokenIssuersCommandOutput extends ListTrustedTokenIssuersResponse, __MetadataBearer {
}
declare const ListTrustedTokenIssuersCommand_base: {
    new (input: ListTrustedTokenIssuersCommandInput): import("@smithy/smithy-client").CommandImpl<ListTrustedTokenIssuersCommandInput, ListTrustedTokenIssuersCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: ListTrustedTokenIssuersCommandInput): import("@smithy/smithy-client").CommandImpl<ListTrustedTokenIssuersCommandInput, ListTrustedTokenIssuersCommandOutput, SSOAdminClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Lists all the trusted token issuers configured in an instance of IAM Identity Center.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { SSOAdminClient, ListTrustedTokenIssuersCommand } from "@aws-sdk/client-sso-admin"; // ES Modules import
 * // const { SSOAdminClient, ListTrustedTokenIssuersCommand } = require("@aws-sdk/client-sso-admin"); // CommonJS import
 * const client = new SSOAdminClient(config);
 * const input = { // ListTrustedTokenIssuersRequest
 *   InstanceArn: "STRING_VALUE", // required
 *   MaxResults: Number("int"),
 *   NextToken: "STRING_VALUE",
 * };
 * const command = new ListTrustedTokenIssuersCommand(input);
 * const response = await client.send(command);
 * // { // ListTrustedTokenIssuersResponse
 * //   TrustedTokenIssuers: [ // TrustedTokenIssuerList
 * //     { // TrustedTokenIssuerMetadata
 * //       TrustedTokenIssuerArn: "STRING_VALUE",
 * //       Name: "STRING_VALUE",
 * //       TrustedTokenIssuerType: "OIDC_JWT",
 * //     },
 * //   ],
 * //   NextToken: "STRING_VALUE",
 * // };
 *
 * ```
 *
 * @param ListTrustedTokenIssuersCommandInput - {@link ListTrustedTokenIssuersCommandInput}
 * @returns {@link ListTrustedTokenIssuersCommandOutput}
 * @see {@link ListTrustedTokenIssuersCommandInput} for command's `input` shape.
 * @see {@link ListTrustedTokenIssuersCommandOutput} for command's `response` shape.
 * @see {@link SSOAdminClientResolvedConfig | config} for SSOAdminClient's `config` shape.
 *
 * @throws {@link AccessDeniedException} (client fault)
 *  <p>You do not have sufficient access to perform this action.</p>
 *
 * @throws {@link InternalServerException} (server fault)
 *  <p>The request processing has failed because of an unknown error, exception, or failure
 *             with an internal server.</p>
 *
 * @throws {@link ThrottlingException} (client fault)
 *  <p>Indicates that the principal has crossed the throttling limits of the API
 *             operations.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The request failed because it contains a syntax error.</p>
 *
 * @throws {@link SSOAdminServiceException}
 * <p>Base exception class for all service exceptions from SSOAdmin service.</p>
 *
 * @public
 */
export declare class ListTrustedTokenIssuersCommand extends ListTrustedTokenIssuersCommand_base {
    /** @internal type navigation helper, not in runtime. */
    protected static __types: {
        api: {
            input: ListTrustedTokenIssuersRequest;
            output: ListTrustedTokenIssuersResponse;
        };
        sdk: {
            input: ListTrustedTokenIssuersCommandInput;
            output: ListTrustedTokenIssuersCommandOutput;
        };
    };
}
